From 22974653a2f7dcb8a304c6c5afc7d52bf17fc2b6 Mon Sep 17 00:00:00 2001
From: ValueOn AG
Date: Mon, 3 Nov 2025 00:38:50 +0100
Subject: [PATCH] automation admin center integrated
---
modules/workflows/processing/modes/modeAutomation.py | 8 ++++----
1 file changed, 4 insertions(+), 4 deletions(-)
diff --git a/modules/workflows/processing/modes/modeAutomation.py b/modules/workflows/processing/modes/modeAutomation.py
index f8415efa..7e1c9ca2 100644
--- a/modules/workflows/processing/modes/modeAutomation.py
+++ b/modules/workflows/processing/modes/modeAutomation.py
@@ -1,5 +1,5 @@
# modeAutomation.py
# Template mode implementation for workflows with predefined action plans
import json
import logging
@@ -14,14 +14,14 @@ from modules.workflows.processing.modes.modeBase import BaseMode
logger = logging.getLogger(__name__)
-class TemplateMode(BaseMode):
- """Template mode implementation - executes workflows from predefined plans"""
+class AutomationMode(BaseMode):
+ """Automation mode implementation - executes workflows from predefined plans"""
def __init__(self, services, workflow):
super().__init__(services, workflow)
# Store action lists for each task (mapped by task ID)
self.taskActionMap: Dict[str, List[Dict[str, Any]]] = {}
- logger.info("TemplateMode initialized - will use predefined plan from workflow")
+ logger.info("AutomationMode initialized - will use predefined plan from workflow")
async def generateTaskPlan(self, userInput: str, workflow: ChatWorkflow) -> TaskPlan:
"""
@@ -1,5 +1,5 @@
# modeAutomation.py
-# Template mode implementation for workflows with predefined action plans
+# Automation mode implementation for workflows with predefined action plans
import json
import logging